@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -25,9 +26,7 @@
  *
  ************************************************************************/
 
-#ifndef _UNIVERSALL_REFERENCE_HXX
 #include "uniref.hxx"
-#endif
 namespace binfilter {
 
 UniRefBase::~UniRefBase()
@@ -40,3 +39,5 @@ void UniRefBase::release()
         delete this; 
 }
 }//end of namespace binfilter
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
