@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -235,7 +236,7 @@ void lcl_mergeProps( PropertyMapPtr pToFill,  PropertyMapPtr pToAdd, TblStyleTyp
         ( nStyleId == TBL_STYLE_FIRSTCOL )
     };
 
-    for ( int i = 0 ; i < 7; i++ )
+    for ( unsigned i = 0 ; i != sizeof(pPropsToCheck) / sizeof(PropertyIds); i++ )
     {
         PropertyIds nId = pPropsToCheck[i];
         PropertyDefinition aProp( nId, false );
@@ -1446,3 +1447,5 @@ void StyleSheetTable::applyDefaults(bool bParaProperties)
 
 }//namespace dmapper
 }//namespace writerfilter
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
